@@ -1,11 +1,11 @@
-import smbus
-from typing import List, Optional
+from smbus2 import SMBus
+from typing import List
 
 
 def scan() -> List[str]:
     devices = []
     try:
-        bus = smbus.SMBus(1) # 1 indicates /dev/i2c-1
+        bus = SMBus(1) # 1 indicates /dev/i2c-1
         for device in range(128):
             try:
                 bus.read_byte(device)
@@ -15,3 +15,4 @@ def scan() -> List[str]:
     except FileNotFoundError as e:
         print("WARNING: I2C seems not to be activated")
     return devices
+
